@@ -5,19 +5,9 @@ Source: https://github.com/BoboTiG/python-mss
 import ctypes
 import ctypes.util
 import sys
-from ctypes import (
-    POINTER,
-    Structure,
-    c_double,
-    c_float,
-    c_int32,
-    c_ubyte,
-    c_uint32,
-    c_uint64,
-    c_void_p,
-)
+from ctypes import POINTER, Structure, c_double, c_float, c_int32, c_ubyte, c_uint32, c_uint64, c_void_p
 from platform import mac_ver
-from typing import Any, Type, Union
+from typing import Any, Optional, Type, Union
 
 from .base import MSSBase
 from .exception import ScreenShotError
@@ -76,11 +66,7 @@ CFUNCTIONS: CFunctions = {
     "CFDataGetLength": ("core", [c_void_p], c_uint64),
     "CFRelease": ("core", [c_void_p], c_void_p),
     "CGDataProviderRelease": ("core", [c_void_p], c_void_p),
-    "CGGetActiveDisplayList": (
-        "core",
-        [c_uint32, POINTER(c_uint32), POINTER(c_uint32)],
-        c_int32,
-    ),
+    "CGGetActiveDisplayList": ("core", [c_uint32, POINTER(c_uint32), POINTER(c_uint32)], c_int32),
     "CGImageGetBitsPerPixel": ("core", [c_void_p], int),
     "CGImageGetBytesPerRow": ("core", [c_void_p], int),
     "CGImageGetDataProvider": ("core", [c_void_p], c_void_p),
@@ -88,11 +74,7 @@ CFUNCTIONS: CFunctions = {
     "CGImageGetWidth": ("core", [c_void_p], int),
     "CGRectStandardize": ("core", [CGRect], CGRect),
     "CGRectUnion": ("core", [CGRect, CGRect], CGRect),
-    "CGWindowListCreateImage": (
-        "core",
-        [CGRect, c_uint32, c_uint32, c_uint32],
-        c_void_p,
-    ),
+    "CGWindowListCreateImage": ("core", [CGRect, c_uint32, c_uint32, c_uint32], c_void_p),
 }
 
 
@@ -104,12 +86,12 @@ class MSS(MSSBase):
 
     __slots__ = {"core", "max_displays"}
 
-    def __init__(self, **_: Any) -> None:
+    def __init__(self, /, **kwargs: Any) -> None:
         """macOS initialisations."""
 
-        super().__init__()
+        super().__init__(**kwargs)
 
-        self.max_displays = 32
+        self.max_displays = kwargs.get("max_displays", 32)
 
         self._init_library()
         self._set_cfunctions()
@@ -121,7 +103,6 @@ class MSS(MSSBase):
             coregraphics = ctypes.util.find_library("CoreGraphics")
         else:
             # macOS Big Sur and newer
-            # pylint: disable=line-too-long
             coregraphics = "/System/Library/Frameworks/CoreGraphics.framework/Versions/Current/CoreGraphics"
 
         if not coregraphics:
@@ -134,12 +115,7 @@ class MSS(MSSBase):
         cfactory = self._cfactory
         attrs = {"core": self.core}
         for func, (attr, argtypes, restype) in CFUNCTIONS.items():
-            cfactory(
-                attr=attrs[attr],
-                func=func,
-                argtypes=argtypes,
-                restype=restype,
-            )
+            cfactory(attrs[attr], func, argtypes, restype)
 
     def _monitors_impl(self) -> None:
         """Get positions of monitors. It will populate self._monitors."""
@@ -156,17 +132,14 @@ class MSS(MSSBase):
         # Each monitor
         display_count = c_uint32(0)
         active_displays = (c_uint32 * self.max_displays)()
-        core.CGGetActiveDisplayList(
-            self.max_displays, active_displays, ctypes.byref(display_count)
-        )
-        rotations = {0.0: "normal", 90.0: "right", -90.0: "left"}
+        core.CGGetActiveDisplayList(self.max_displays, active_displays, ctypes.byref(display_count))
         for idx in range(display_count.value):
             display = active_displays[idx]
             rect = core.CGDisplayBounds(display)
             rect = core.CGRectStandardize(rect)
             width, height = rect.size.width, rect.size.height
-            rot = core.CGDisplayRotation(display)
-            if rotations[rot] in ["left", "right"]:
+            if core.CGDisplayRotation(display) in {90.0, -90.0}:
+                # {0.0: "normal", 90.0: "right", -90.0: "left"}
                 width, height = height, width
             self._monitors.append(
                 {
@@ -188,15 +161,13 @@ class MSS(MSSBase):
             "height": int_(all_monitors.size.height),
         }
 
-    def _grab_impl(self, monitor: Monitor) -> ScreenShot:
+    def _grab_impl(self, monitor: Monitor, /) -> ScreenShot:
         """Retrieve all pixels from a monitor. Pixels have to be RGB."""
 
         # pylint: disable=too-many-locals
 
         core = self.core
-        rect = CGRect(
-            (monitor["left"], monitor["top"]), (monitor["width"], monitor["height"])
-        )
+        rect = CGRect((monitor["left"], monitor["top"]), (monitor["width"], monitor["height"]))
 
         image_ref = core.CGWindowListCreateImage(rect, 1, 0, 0)
         if not image_ref:
@@ -232,3 +203,7 @@ class MSS(MSSBase):
                 core.CFRelease(copy_data)
 
         return self.cls_image(data, monitor, size=Size(width, height))
+
+    def _cursor_impl(self) -> Optional[ScreenShot]:
+        """Retrieve all cursor data. Pixels have to be RGB."""
+        return None
